@@ -3,7 +3,7 @@
  * gedit-file-selector-util.c
  * This file is part of gedit
  *
- * Copyright (C) 2001-2002 Paolo Maggi 
+ * Copyright (C) 2001-2004 Paolo Maggi 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
  */
  
 /*
- * Modified by the gedit Team, 1998-2002. See the AUTHORS file for a 
+ * Modified by the gedit Team, 2001-2004. See the AUTHORS file for a 
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  */
@@ -62,7 +62,6 @@
 
 #include <libgnomevfs/gnome-vfs.h>
 #include <eel/eel-vfs-extensions.h>
-#include <eel/eel-string.h>
 #include <eel/eel-alert-dialog.h>
 
 #include "gedit-utils.h"
@@ -91,6 +90,7 @@ replace_dialog (GtkWindow *parent,
 		const gchar *secondary_message)
 {
 	GtkWidget *msgbox;
+	AtkObject *obj;
 	gint ret;
 	gchar *full_formatted_uri;
        	gchar *uri_for_display	;
@@ -100,7 +100,7 @@ replace_dialog (GtkWindow *parent,
 	uri = eel_make_uri_from_shell_arg (file_name);
 	g_return_val_if_fail (uri != NULL, FALSE);
 
-	full_formatted_uri = eel_format_uri_for_display (uri);
+	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 	g_return_val_if_fail (full_formatted_uri != NULL, FALSE);
 	g_free (uri);
 	
@@ -108,7 +108,7 @@ replace_dialog (GtkWindow *parent,
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
-        uri_for_display = eel_str_middle_truncate (full_formatted_uri, 50);
+        uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 50);
 	g_return_val_if_fail (uri_for_display != NULL, FALSE);
 	g_free (full_formatted_uri);
 
@@ -134,6 +134,10 @@ replace_dialog (GtkWindow *parent,
 
 	gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_CANCEL);
 
+	obj = gtk_widget_get_accessible (msgbox);
+	if (GTK_IS_ACCESSIBLE (obj))
+		atk_object_set_name (obj, _("Question"));
+
 	ret = gtk_dialog_run (GTK_DIALOG (msgbox));
 	gtk_widget_destroy (msgbox);
 
@@ -332,6 +336,7 @@ create_gtk_selector (GtkWindow *parent,
 		     const char *title,
 		     const char *default_path,
 		     const char *default_filename,
+		     const char *untitled_name,
 		     gboolean use_encoding,
 		     const GeditEncoding *encoding)
 {
@@ -410,12 +415,36 @@ create_gtk_selector (GtkWindow *parent,
 					encoding);
 
 	}
-	
-	if (default_path)
-		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (filesel), default_path);
 
-	if (default_filename)
-		gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (filesel), default_filename);
+	if (mode != FILESEL_SAVE)
+	{	
+		if (default_path != NULL)
+			gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (filesel), default_path);
+	}
+	else
+	{
+		if (default_filename == NULL)
+		{
+			if (default_path != NULL)
+			{
+				gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (filesel), default_path);
+			}
+
+			g_return_val_if_fail (untitled_name != NULL, GTK_WINDOW (filesel));
+			gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (filesel), untitled_name);
+		}
+		else
+		{
+			if (default_path != NULL)
+			{
+				gchar *uri;
+
+				uri = g_strconcat (default_path, "/", default_filename, NULL);
+				gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (filesel), uri);
+				g_free (uri);
+			}
+		}
+	}
 
 	if (mode == FILESEL_OPEN_MULTI) 
 		gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER (filesel), TRUE);
@@ -430,6 +459,7 @@ run_file_selector (GtkWindow  *parent,
 		   const char *title,
 		   const char *default_path, 
 		   const char *default_filename,
+		   const char *untitled_name,
 		   const GeditEncoding **encoding)
 
 {
@@ -442,12 +472,16 @@ run_file_selector (GtkWindow  *parent,
 				      title,
 				      default_path, 
 				      default_filename, 
+				      untitled_name,
 				      (encoding != NULL),
 				      (encoding != NULL) ? *encoding : NULL);
 
 	SET_MODE (dialog, mode);
 	SET_ENABLE_VFS (dialog, enable_vfs);
 	
+	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), 
+					 !enable_vfs);
+
 	gtk_window_set_modal (dialog, TRUE);
 
 	gtk_widget_show_all (GTK_WIDGET (dialog));
@@ -497,7 +531,7 @@ gedit_file_selector_open (GtkWindow  *parent,
 {
 	return run_file_selector (parent, enable_vfs, FILESEL_OPEN, 
 				  title ? title : _("Select a file to open"),
-				  default_path, NULL, encoding);
+				  default_path, NULL, NULL, encoding);
 }
 
 /**
@@ -523,7 +557,7 @@ gedit_file_selector_open_multi (GtkWindow  *parent,
 {
 	return run_file_selector (parent, enable_vfs, FILESEL_OPEN_MULTI,
 				  title ? title : _("Select files to open"),
-				  default_path, NULL, encoding);
+				  default_path, NULL, NULL, encoding);
 }
 
 /**
@@ -533,6 +567,7 @@ gedit_file_selector_open_multi (GtkWindow  *parent,
  * @title: optional window title to use
  * @default_path: optional directory to start in (must be an URI)
  * @default_filename: optional file name to default to
+ * @untitled_name: optional untitled name (valid UTF-8)
  *
  * Creates and shows a modal save file dialog, waiting for the user to
  * select a file or cancel before returning.
@@ -546,9 +581,13 @@ gedit_file_selector_save (GtkWindow  *parent,
 			   const char *title,
 			   const char *default_path, 
 			   const char *default_filename,
+			   const char *untitled_name,
 			   const GeditEncoding **encoding)
 {
+	g_return_val_if_fail (((default_filename != NULL) && (untitled_name == NULL)) ||
+                              ((default_filename == NULL) && (untitled_name != NULL)), NULL);
+
 	return run_file_selector (parent, enable_vfs, FILESEL_SAVE,
 				  title ? title : _("Select a filename to save"),
-				  default_path, default_filename, encoding);
+				  default_path, default_filename, untitled_name, encoding);
 }
