@@ -397,20 +397,17 @@ gedit_utils_error_reporting_loading_file (
 	gchar *full_formatted_uri;
        	gchar *uri_for_display	;
 	gchar *encoding_name = NULL;
-	
-	GnomeVFSURI *vfs_uri;
-	
 	GtkWidget *dialog;
 
 	g_return_if_fail (uri != NULL);
 	
-	full_formatted_uri = eel_format_uri_for_display (uri);
+	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
-        uri_for_display = eel_str_middle_truncate (full_formatted_uri, 
+        uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
 			MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
@@ -439,7 +436,7 @@ gedit_utils_error_reporting_loading_file (
 				break;			 
 	
 			case GNOME_VFS_ERROR_NOT_SUPPORTED:
-				scheme_string = eel_uri_get_scheme (uri);
+				scheme_string = gnome_vfs_get_uri_scheme (uri);
                 
 				if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
 				{
@@ -517,31 +514,51 @@ gedit_utils_error_reporting_loading_file (
 			 	* the proxy is set up wrong.
 		 		*/
 				{
-					gchar *host_name;
+					GnomeVFSURI *vfs_uri;
+
 					vfs_uri = gnome_vfs_uri_new (uri);
-				
+
 					if (vfs_uri == NULL)
-						host_name = g_strdup ("XXX");
+					{
+						/* use the same string as INVALID_HOST */
+						error_message = g_strdup_printf (
+						_("Could not open the file \"%s\" because the host name "
+						  "was invalid.\n\n"
+						  "Please, check that you typed the location correctly "
+						  "and try again."),
+						  uri_for_display);
+					}
 					else
 					{
-						host_name = eel_make_valid_utf8 (
-							gnome_vfs_uri_get_host_name (vfs_uri));
+						const gchar *hn = gnome_vfs_uri_get_host_name (vfs_uri);
 
+						if (hn == NULL)
+						{
+							/* use the same string as INVALID_HOST */
+							error_message = g_strdup_printf (
+							_("Could not open the file \"%s\" because the host name "
+							  "was invalid.\n\n"
+							  "Please, check that you typed the location correctly "
+							  "and try again."),
+							  uri_for_display);
+						}
+						else
+						{
+							gchar *host_name = eel_make_valid_utf8 (hn);
+
+							error_message = g_strdup_printf (
+							_("Could not open the file \"%s\" because no host \"%s\" " 
+							  "could be found.\n\n"
+							  "Please, check that you typed the location correctly "
+							  "and that your proxy settings are correct and then "
+							  "try again."),
+							  uri_for_display, host_name);
+
+							g_free (host_name);
+						}
 						gnome_vfs_uri_unref (vfs_uri);		
 					}
-				
-	                		error_message = g_strdup_printf (
-						_("Could not open the file \"%s\" because no host \"%s\" " 
-					  	  "could be found.\n\n"
-                			  	  "Please, check that you typed the location correctly "
-					  	  "and that your proxy settings are correct and then "
-				  		  "try again."),
-						  uri_for_display,
-						  host_name);
-
-					g_free (host_name);
 				}
-
 				break;
 
 			case GNOME_VFS_ERROR_INVALID_HOST_NAME:
@@ -724,13 +741,13 @@ gedit_utils_error_reporting_saving_file (
 	g_return_if_fail (uri != NULL);
 	g_return_if_fail (error != NULL);
 	
-	full_formatted_uri = eel_format_uri_for_display (uri);
+	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
-        uri_for_display = eel_str_middle_truncate (full_formatted_uri, 
+        uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
 			MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
@@ -771,9 +788,6 @@ gedit_utils_error_reporting_reverting_file (
 	gchar *error_message;
 	gchar *full_formatted_uri;
        	gchar *uri_for_display	;
-	
-	GnomeVFSURI *vfs_uri;
-	
 	GtkWidget *dialog;
 
 	g_return_if_fail (uri != NULL);
@@ -785,7 +799,7 @@ gedit_utils_error_reporting_reverting_file (
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
-        uri_for_display = eel_str_middle_truncate (full_formatted_uri, 
+        uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
 			MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
@@ -806,7 +820,7 @@ gedit_utils_error_reporting_reverting_file (
 			break;			 
 
 		case GNOME_VFS_ERROR_NOT_SUPPORTED:
-			scheme_string = eel_uri_get_scheme (uri);
+			scheme_string = gnome_vfs_get_uri_scheme (uri);
                 
 			if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
 			{
@@ -868,30 +882,44 @@ gedit_utils_error_reporting_reverting_file (
 		 	* the proxy is set up wrong.
 		 	*/
 			{
-				gchar *host_name;
+				GnomeVFSURI *vfs_uri;
+
 				vfs_uri = gnome_vfs_uri_new (uri);
-				
+
 				if (vfs_uri == NULL)
-					host_name = g_strdup ("XXX");
+				{
+					/* use the default string */
+					error_message = g_strdup_printf (
+		                        	_("Could not revert the file \"%s\"."),
+					 	uri_for_display);
+				}
 				else
 				{
-					host_name = eel_make_valid_utf8 (
-							gnome_vfs_uri_get_host_name (vfs_uri));
+					const gchar *hn = gnome_vfs_uri_get_host_name (vfs_uri);
 
+					if (hn == NULL)
+					{
+						/* use the default string */
+						error_message = g_strdup_printf (
+			                        	_("Could not revert the file \"%s\"."),
+						 	uri_for_display);
+					}
+					else
+					{
+						gchar *host_name = eel_make_valid_utf8 (hn);
+
+						error_message = g_strdup_printf (
+						_("Could not revert the file \"%s\" because no host \"%s\" " 
+					  	  "could be found.\n\n"
+        	        		  	  "Please, check that your proxy settings are correct and "
+					  	  "try again."),
+						  uri_for_display, host_name);
+
+						g_free (host_name);
+					}
 					gnome_vfs_uri_unref (vfs_uri);		
 				}
-				
-				error_message = g_strdup_printf (
-					_("Could not revert the file \"%s\" because no host \"%s\" " 
-				  	  "could be found.\n\n"
-                		  	  "Please, check that your proxy settings are correct and "
-				  	  "try again."),
-					  uri_for_display,
-					  host_name);
-
-				g_free (host_name);
 			}
-
 			break;
             
 		case GNOME_VFS_ERROR_HOST_HAS_NO_ADDRESS:
@@ -995,13 +1023,13 @@ gedit_utils_error_reporting_creating_file (
 
 	g_return_if_fail (uri != NULL);
 	
-	full_formatted_uri = eel_format_uri_for_display (uri);
+	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
-        uri_for_display = eel_str_middle_truncate (full_formatted_uri, 
+        uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
 			MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
@@ -1309,3 +1337,49 @@ gedit_warning (GtkWindow *parent, gchar *format, ...)
 	g_free (str);
 }
 
+/* taken from eel, except that we use "…" instead of "..."*/
+gchar *
+gedit_utils_str_middle_truncate (const char *string,
+				 guint truncate_length)
+{
+	char *truncated;
+	guint length;
+	guint num_left_chars;
+	guint num_right_chars;
+
+	const char delimter[] = "…";
+	const guint delimter_length = strlen (delimter);
+	const guint min_truncate_length = delimter_length + 2;
+
+	if (string == NULL) {
+		return NULL;
+	}
+
+	/* It doesnt make sense to truncate strings to less than
+	 * the size of the delimiter plus 2 characters (one on each
+	 * side)
+	 */
+	if (truncate_length < min_truncate_length) {
+		return g_strdup (string);
+	}
+
+	length = strlen (string);
+
+	/* Make sure the string is not already small enough. */
+	if (length <= truncate_length) {
+		return g_strdup (string);
+	}
+
+	/* Find the 'middle' where the truncation will occur. */
+	num_left_chars = (truncate_length - delimter_length) / 2;
+	num_right_chars = truncate_length - num_left_chars - delimter_length + 1;
+
+	truncated = g_new (char, truncate_length + 1);
+
+	strncpy (truncated, string, num_left_chars);
+	strncpy (truncated + num_left_chars, delimter, delimter_length);
+	strncpy (truncated + num_left_chars + delimter_length, string + length - num_right_chars + 1, num_right_chars);
+	
+	return truncated;
+}
+
